@@ -19,14 +19,14 @@ import sys
 
 modname = distname = 'pylint'
 
-numversion = (1, 2, 0)
+numversion = (1, 3, 1)
 version = '.'.join([str(num) for num in numversion])
 
 if sys.version_info < (2, 6):
-    install_requires = ['logilab-common >= 0.53.0', 'astroid >= 1.1',
+    install_requires = ['logilab-common >= 0.53.0', 'astroid >= 1.2.1',
                         'StringFormat']
 else:
-    install_requires = ['logilab-common >= 0.53.0', 'astroid >= 1.1']
+    install_requires = ['logilab-common >= 0.53.0', 'astroid >= 1.2.1']
 
 license = 'GPL'
 description = "python code static checker"
@@ -45,8 +45,8 @@ classifiers = ['Development Status :: 4 - Beta',
                'Programming Language :: Python :: 3',
                'Topic :: Software Development :: Debuggers',
                'Topic :: Software Development :: Quality Assurance',
-               'Topic :: Software Development :: Testing',
-               ]
+               'Topic :: Software Development :: Testing'
+              ]
 
 
 long_desc = """\
