@@ -107,6 +107,11 @@ MSGS = {
               'clauses. '
               'See http://www.python.org/dev/peps/pep-3110/',
               {'maxversion': (3, 0)}),
+    'W0713': ('Indexing exceptions will not work on Python 3',
+              'indexing-exception',
+              'Indexing exceptions will not work on Python 3. Use '
+              '`exception.args[index]` instead.',
+              {'maxversion': (3, 0)}),
     }
 
 
@@ -132,8 +137,8 @@ class ExceptionsChecker(BaseChecker):
                  'help' : 'Exceptions that will emit a warning '
                           'when being caught. Defaults to "%s"' % (
                               ', '.join(OVERGENERAL_EXCEPTIONS),)}
-                ),
-               )
+               ),
+              )
 
     @check_messages('raising-string', 'nonstandard-exception', 'raising-bad-type',
                     'raising-non-exception', 'notimplemented-raised', 'bad-exception-context')
@@ -148,6 +153,8 @@ class ExceptionsChecker(BaseChecker):
             except astroid.InferenceError:
                 pass
             else:
+                if cause is YES:
+                    return
                 if isinstance(cause, astroid.Const):
                     if cause.value is not None:
                         self.add_message('bad-exception-context',
@@ -155,7 +162,7 @@ class ExceptionsChecker(BaseChecker):
                 elif (not isinstance(cause, astroid.Class) and
                       not inherit_from_std_ex(cause)):
                     self.add_message('bad-exception-context',
-                                      node=node)
+                                     node=node)
         expr = node.exc
         if self._check_raise_value(node, expr):
             return
@@ -211,6 +218,17 @@ class ExceptionsChecker(BaseChecker):
         if isinstance(node.name, (astroid.Tuple, astroid.List)):
             self.add_message('unpacking-in-except', node=node)
 
+    @check_messages('indexing-exception')
+    def visit_subscript(self, node):
+        """ Look for indexing exceptions. """
+        try:
+            for infered in node.value.infer():
+                if not isinstance(infered, astroid.Instance):
+                    continue
+                if inherit_from_std_ex(infered):
+                    self.add_message('indexing-exception', node=node)
+        except astroid.InferenceError:
+            return
 
     @check_messages('bare-except', 'broad-except', 'pointless-except',
                     'binary-op-exception', 'bad-except-order',
@@ -221,14 +239,14 @@ class ExceptionsChecker(BaseChecker):
         nb_handlers = len(node.handlers)
         for index, handler  in enumerate(node.handlers):
             # single except doing nothing but "pass" without else clause
-            if nb_handlers == 1 and is_empty(handler.body) and not node.orelse:
+            if is_empty(handler.body) and not node.orelse:
                 self.add_message('pointless-except', node=handler.type or handler.body[0])
             if handler.type is None:
-                if nb_handlers == 1 and not is_raising(handler.body):
+                if not is_raising(handler.body):
                     self.add_message('bare-except', node=handler)
                 # check if a "except:" is followed by some other
                 # except
-                elif index < (nb_handlers - 1):
+                if index < (nb_handlers - 1):
                     msg = 'empty except clause should always appear last'
                     self.add_message('bad-except-order', node=node, args=msg)
 
@@ -251,12 +269,12 @@ class ExceptionsChecker(BaseChecker):
                                 previous_exc.name, exc.name)
                             self.add_message('bad-except-order', node=handler.type, args=msg)
                     if (exc.name in self.config.overgeneral_exceptions
-                        and exc.root().name == EXCEPTIONS_MODULE
-                        and nb_handlers == 1 and not is_raising(handler.body)):
+                            and exc.root().name == EXCEPTIONS_MODULE
+                            and not is_raising(handler.body)):
                         self.add_message('broad-except', args=exc.name, node=handler.type)
 
                     if (not inherit_from_std_ex(exc) and
-                        exc.root().name != BUILTINS_NAME):
+                            exc.root().name != BUILTINS_NAME):
                         # try to see if the exception is based on a C based
                         # exception, by infering all the base classes and
                         # looking for inference errors
