@@ -1,9 +1,9 @@
-# pylint: disable-msg=R0903
+# pylint: disable=R0903
 """yo"""
 
 __revision__ = '$I$'
 
-class Aaaa:
+class Aaaa(object):
     """class with attributes defined in wrong order"""
     def __init__(self):
         var1 = self._var2
@@ -13,19 +13,19 @@ class Aaaa:
 class Bbbb(object):
     """hop"""
     __revision__ = __revision__ # no problemo marge
-    
+
     def __getattr__(self, attr):
-        # pylint: disable-msg=W0201
+        # pylint: disable=W0201
         try:
             return self.__repo
         except AttributeError:
             self.__repo = attr
             return attr
 
-    
+
     def catchme(self, attr):
         """no AttributeError catched"""
-        # pylint: disable-msg=W0201
+        # pylint: disable=W0201
         try:
             return self._repo
         except ValueError:
