@@ -4,7 +4,7 @@
 __revision__ = 0
 
 
-class Abcd:
+class Abcd(object):
     """dummy class"""
     def __init__(self):
         pass
@@ -16,3 +16,4 @@ class Abcd:
 
     def edf(self):
         """justo ne more method"""
+        print 'yapudju in', self
