@@ -16,15 +16,15 @@ def func(xxx): return xxx
 
 def func2(xxx): return xxx + func2(1)
 
-import sys; print sys.exc_info( )
+import sys; print sys.exc_info()
 
 for i in range(10): print i
 
 j = 4; LAMB = lambda x: x+j
 
-FUNC4 = lambda a, b : a != b
-FUNC3 = lambda (a, b) : a != b
+FUNC4 = lambda a, b: a != b
+FUNC3 = lambda (a, b): a != b
 
 # test http://www.logilab.org/ticket/6954:
 
-with open('f') as f: print(f.read())
+with open('f') as f: print f.read()
